/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudtrail.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.cloudtrail.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * CreateTrailResult JSON Unmarshaller
 */
public class CreateTrailResultJsonUnmarshaller implements
        Unmarshaller<CreateTrailResult, JsonUnmarshallerContext> {

    public CreateTrailResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        CreateTrailResult createTrailResult = new CreateTrailResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("Name", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setName(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("S3BucketName", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setS3BucketName(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("S3KeyPrefix", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setS3KeyPrefix(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("SnsTopicName", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setSnsTopicName(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("SnsTopicARN", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setSnsTopicARN(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("IncludeGlobalServiceEvents",
                        targetDepth)) {
                    context.nextToken();
                    createTrailResult
                            .setIncludeGlobalServiceEvents(context
                                    .getUnmarshaller(Boolean.class).unmarshall(
                                            context));
                }
                if (context.testExpression("IsMultiRegionTrail", targetDepth)) {
                    context.nextToken();
                    createTrailResult
                            .setIsMultiRegionTrail(context.getUnmarshaller(
                                    Boolean.class).unmarshall(context));
                }
                if (context.testExpression("TrailARN", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setTrailARN(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("LogFileValidationEnabled",
                        targetDepth)) {
                    context.nextToken();
                    createTrailResult
                            .setLogFileValidationEnabled(context
                                    .getUnmarshaller(Boolean.class).unmarshall(
                                            context));
                }
                if (context.testExpression("CloudWatchLogsLogGroupArn",
                        targetDepth)) {
                    context.nextToken();
                    createTrailResult.setCloudWatchLogsLogGroupArn(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context
                        .testExpression("CloudWatchLogsRoleArn", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setCloudWatchLogsRoleArn(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("KmsKeyId", targetDepth)) {
                    context.nextToken();
                    createTrailResult.setKmsKeyId(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return createTrailResult;
    }

    private static CreateTrailResultJsonUnmarshaller instance;

    public static CreateTrailResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateTrailResultJsonUnmarshaller();
        return instance;
    }
}
